=begin
#-----------------------------------------------------------------------
Creative Commons (cc) Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
you are free to:
Share — copy and redistribute the material in any medium or format
Adapt — remix, transform, and build upon the material
for any purpose, even commercially.
The licensor cannot revoke these freedoms as long as you follow the license terms.
Under the following terms:
Attribution — You must give appropriate credit, provide a link to the license, and indicate if changes were made. You may do so in any reasonable manner, but not in any way that suggests the licensor endorses you or your use.
ShareAlike — If you remix, transform, or build upon the material, you must distribute your contributions under the same license as the original.
No additional restrictions — You may not apply legal terms or technological measures that legally restrict others from doing anything the license permits.
Name :  	Vico-Section
Inspiration : 
Author :	Vincent Courteaux vico@regard.org
Usage : 	créer dans le dossier /TEMP un fichier corespondant au composant dynamique puis l'ouvre dans sketchup
        	
History: 1.0 	First release. 20160416 
History: 1.1 	First release. 20190122 ajout de la création d'un Xref dans le dossier /XREF et de "recharger" 
		 
      
#-----------------------------------------------------------------------
=end

module VICO

	def self.sauver
		model = Sketchup.active_model
		file_dir = File.dirname(model.path)
		xref_dir = file_dir + "/XREF/"
        composant = Sketchup.active_model.selection[0]
        filename = composant.definition.name + ".skp"
		definition = composant.definition
		definition.save_as xref_dir + filename    
    end # sauver
    
    def self.ouvrir
    	model = Sketchup.active_model
    	file_dir = File.dirname(model.path)
		temp_dir = file_dir + "/TEMP_FILE/"
        composant = Sketchup.active_model.selection[0]
        filename = composant.definition.name + ".skp"
		definition = composant.definition
		path = definition.path
		if File.exist?(path)
				definition.save_as path
				composant.locked = true
				model.save
				Sketchup.open_file path  
			else
				definition.save_as temp_dir + filename
				composant.locked = true
				model.save
				Sketchup.open_file temp_dir + filename  
			end		           
    end # ouvrir
    
    
    def self.reload
    	model = Sketchup.active_model
    	select_composant = Sketchup.active_model.selection[0] 
        old_definition = select_composant.definition
        good_name = old_definition.name
        filename = good_name + ".skp"
        path = old_definition.path
  			if File.exist?(path)
  				model.start_operation("préparation",true)
  				select_composant.locked = false
  				entities = old_definition.entities
        		entities.add_cpoint(ORIGIN)
        		model.commit_operation     		
    			new_definition = model.definitions.load(path)
    			model.start_operation("remplacer",true)   			
    			new_definition.name = good_name
    			if new_definition
    				old_definition.instances.each{|i| i.definition = new_definition }
    				model.definitions.remove(old_definition.name)
    			else
      				UI.messagebox("Error: Could not load component: \"#{File.basename(filename,".*")}\"")
    			end
    			model.commit_operation   			
  			else UI.messagebox("Error: Could not find file:\n\"#{path}\"" )
  			end
	end # reload
    

end # module

UI.add_context_menu_handler do | menu |
	if Sketchup.active_model.selection.length==1 and Sketchup.active_model.selection[0].kind_of?(Sketchup::ComponentInstance)			
		menu.add_separator
		url = Sketchup.active_model.selection[0].get_attribute(:linkfile, :url)
		if url
			menu.add_item("Open Linked File (#{url})") { 
				Sketchup.open_file(url)
			}
		end
		menu.add_item("créer ou enregistrer un X-Ref") {VICO.sauver}
		menu.add_item("ouvrir à part") {VICO.ouvrir}
		menu.add_item("recharger") {VICO.reload}
	end
end
